@@ -9,18 +9,23 @@ from . import utils
 
 class CustomHelpCommand(commands.MinimalHelpCommand):
 
-    def __init__(self, **options):
-        self.include_invite = options.pop("include_invite", False)
-        super().__init__(**options)
-
-    async def filter_commands(self, commands:typing.List[utils.Command]) -> typing.List[utils.Command]:
+    async def filter_commands(self, commands_to_filter:typing.List[utils.Command]) -> typing.List[utils.Command]:
         """
         Filter the command list down into a list of runnable commands.
         """
 
         if self.context.author.id in self.context.bot.owner_ids:
-            return commands
-        return [i for i in commands if i.hidden is False and i.enabled is True]
+            return [i for i in commands_to_filter if i.name != "help"]
+        valid_commands = [i for i in commands_to_filter if i.hidden is False and i.enabled is True and i.name != "help"]
+        returned_commands = []
+        for comm in valid_commands:
+            try:
+                await comm.can_run(self.context)
+            except commands.CommandError as e:
+                if isinstance(e, (commands.DisabledCommand, commands.NotOwner)):
+                    continue
+            returned_commands.append(comm)
+        return returned_commands
 
     def get_command_signature(self, command:commands.Command):
         return '{0.clean_prefix}{1.qualified_name} {1.signature}'.format(self, command)
@@ -61,7 +66,7 @@ class CustomHelpCommand(commands.MinimalHelpCommand):
         runnable_commands = {}
         for cog, cog_commands in mapping.items():
             available_commands = await self.filter_commands(cog_commands)
-            if len(available_commands) > 0:
+            if len(available_commands) > 0 or isinstance(cog, (commands.Command, commands.Group,)):
                 runnable_commands[cog] = available_commands
 
         # Make an embed
@@ -74,8 +79,10 @@ class CustomHelpCommand(commands.MinimalHelpCommand):
             command_strings.append((getattr(cog, 'get_name', lambda: cog.name)(), value))
 
             # See if it's a command with subcommands
+            if isinstance(cog, commands.Group):
+                help_embed.description = self.get_help_line(cog, with_signature=cog.invoke_without_command)
             if isinstance(cog, commands.Command):
-                help_embed.description = self.get_help_line(cog)
+                help_embed.description = self.get_help_line(cog, with_signature=True)
 
         # Order embed by length before embedding
         command_strings.sort(key=lambda x: len(x[1]), reverse=True)
@@ -88,8 +95,9 @@ class CustomHelpCommand(commands.MinimalHelpCommand):
 
         # Send it to the destination
         data = {"embed": help_embed}
-        if self.include_invite:
-            data.update({"content": self.context.bot.config['command_data']['guild_invite']})
+        content = self.context.bot.config.get("help_command", {}).get("content", None)
+        if content:
+            data.update({"content": content.format(bot=self.context.bot, prefix=self.clean_prefix)})
         await self.send_to_destination(**data)
 
     async def send_to_destination(self, *args, **kwargs):
@@ -113,6 +121,8 @@ class CustomHelpCommand(commands.MinimalHelpCommand):
                     await self.context.send("I couldn't send you a DM :c")
                 except discord.Forbidden:
                     pass  # Oh no now they won't know anything
+            except discord.HTTPException as e:
+                await self.context.send(f"I couldn't send you the help DM - {e}")  # We couldn't send the embed for some other reason
             return
 
         # If the destination is a channel
@@ -120,6 +130,8 @@ class CustomHelpCommand(commands.MinimalHelpCommand):
             await dest.send(*args, **kwargs)
         except discord.Forbidden:
             pass  # Can't talk in the channel? Shame
+        except discord.HTTPException as e:
+            await self.context.send(f"I couldn't send you the help DM - {e}")  # We couldn't send the embed for some other reason
 
     async def send_error_message(self, error):
         """
@@ -141,14 +153,27 @@ class CustomHelpCommand(commands.MinimalHelpCommand):
         embed.colour = random.randint(1, 0xffffff)
         return embed
 
-    def get_help_line(self, command:utils.Command):
+    def get_help_line(self, command:utils.Command, with_signature:bool=False):
         """
         Gets a doc line of help for a given command.
         """
 
         if command.short_doc:
-            return f"**{self.clean_prefix}{command.qualified_name}** - {command.short_doc}"
-        return f"**{self.clean_prefix}{command.qualified_name}**"
+            v = f"**{self.clean_prefix}{command.qualified_name}** - {command.short_doc}"
+        else:
+            v = f"**{self.clean_prefix}{command.qualified_name}**"
+        if with_signature:
+            v += f"\n`{self.clean_prefix}{command.qualified_name} {command.signature}`"
+        return v
+
+    def get_destination(self):
+        """
+        Return where we want the bot to send the embed to
+        """
+
+        if self.context.bot.config.get("help_command", {}).get("dm_help", True):
+            return self.context.author
+        return self.context.channel
 
 
 class Help(utils.Cog):
